@@ -2,7 +2,7 @@
 # housekeeping
 #######################################################################
 
-package Object::Exercise    v3.0.1;
+package Object::Exercise    v3.1.0;
 use v5.20;
 
 use Symbol qw( qualify qualify_to_ref );
@@ -140,10 +140,9 @@ for method calls.
 
         q{noverbose}
 
-        # turn on/off a breakpoint prior to execution or if the
-        # next step returns an error.
+        # turn on elapsed and wallclock time output.
 
-        ...
+        q{benchmark},
 
         # set a breakpoint via $DB::single = 1 prior to calling
         # $object->$method for all following tests.
@@ -315,6 +314,13 @@ the method. The line following this breakpoint is:
 
 which can be used to immediately check why a call failed.
 
+=item counter (default 0)
+
+Outputs a ++n counter from 1 .. number of steps. Turning
+this on allows tracking total steps run for progressive
+execution (e.g., when noplan is used for testing multiple
+objects).
+
 =back
 
 =head1 Exercising Objects
