@@ -2,7 +2,7 @@
 # housekeeping
 #######################################################################
 
-package Object::Exercise::Execute   v3.0.1;
+package Object::Exercise::Execute   v3.1.1;
 use v5.20;
 no warnings;
 
@@ -25,6 +25,7 @@ my @defaultz =
 qw
 (
     benchmark   0
+    counter     0
     break       0
     regex       0
 
@@ -66,7 +67,7 @@ sub extract_flags
         exists $globalz{ $name }
         or do
         {
-            note "$_";
+            diag "Unknown option: '$_'";
             next
         };
 
@@ -114,12 +115,13 @@ my $execute
     state $r    = [];
     state $t0   = '';
     state $t1   = '';
+    state $n    = 0;
 
     my ( $obj, $test ) = @_;
 
     my ( $method, @argz ) = @$test;
 
-    # assume that "$return =" is not significant in the benchmark.
+    # assume that "@$r =" is not significant in the benchmark.
     # also assume that nothing in gettimeofday will set $@.
 
     @$r = ();
@@ -134,18 +136,23 @@ my $execute
     };
     chomp( my $error = $@ );
 
+    if( $globalz{ counter   } )
+    {
+        note 'Instruction: ' . ++$n;
+    }
+
     if( $globalz{ benchmark } )
     {
         state $format   = "Benchmark: %0.6f sec\t%s( %s )";
 
         my $wall        = tv_interval $t0, $t1;
 
-        diag sprintf $format => $wall, $method, explain @argz;
+        note sprintf $format => $wall, $method, explain @argz;
     }
 
     if( $error )
     {
-        note "Error: '$method'\n", explain $error;
+        diag "Error: '$method'\n", explain $error;
     }
     elsif( $globalz{ verbose } )
     {
@@ -154,6 +161,9 @@ my $execute
 
     if( $error && $globalz{ debug } )
     {
+        # stop here where the error is visible and the
+        # test contents are still in scope.
+
         $DB::single = 1;
         0
     }
